@@ -1,10 +1,29 @@
 package t::Helper;
 use Mojo::Base -strict;
+use Mojo::Util;
 use Cookieville;
 use t::Schema;
 
 my $DB_FILE;
 
+sub client {
+  my ($class, $t) = @_;
+  require Cookieville::Client;
+  my $client = Cookieville::Client->new(url => '/');
+  $client->_ua($t->ua);
+  $client;
+}
+
+sub client_cb {
+  ($::err, $::res) = ('', undef);
+
+  return sub {
+    my $client = shift;
+    ($::err, $::res) = @_;
+    $client->_ua->ioloop->stop;
+  };
+}
+
 sub t {
   my $app = Cookieville->new;
   my $t = Test::Mojo->new($app);
@@ -29,6 +48,8 @@ sub import {
   strict->import;
   warnings->import;
 
+  Mojo::Util::monkey_patch($caller => d => \&Mojo::Util::dumper);
+
   eval <<"  CODE" or die $@;
     package $caller;
     use Test::Mojo;
